@@ -19,11 +19,11 @@ TAP::Parser::Iterator::Process - Internal TAP::Parser Iterator
 
 =head1 VERSION
 
-Version 3.02
+Version 3.03
 
 =cut
 
-$VERSION = '3.02';
+$VERSION = '3.03';
 
 =head1 SYNOPSIS
 
@@ -259,7 +259,7 @@ sub _next {
                 }
 
                 # Return partial last line
-                if ($partial) {
+                if ( length $partial ) {
                     my $last = $partial;
                     $partial = '';
                     return $last;
