@@ -27,11 +27,11 @@ TAP::Parser::Result - TAP::Parser output
 
 =head1 VERSION
 
-Version 3.02
+Version 3.03
 
 =cut
 
-$VERSION = '3.02';
+$VERSION = '3.03';
 
 =head2 DESCRIPTION
 
@@ -206,7 +206,7 @@ Indicates whether or not the given result has a TODO or SKIP directive.
 
 sub has_directive {
     my $self = shift;
-    return ( $self->has_todo || $self->has_skip ) || '';
+    return ( $self->has_todo || $self->has_skip );
 }
 
 ##############################################################################
